public class Vector implements Cloneable {
    private int[] a;
    public Vector(int[] a) {
        // Arrays koennen einfach kopiert werden
        this.a = (int[]) a.clone();
    }
    public void multiplyBy(int f) {
        for (int i = 0; i < a.length; i++)
	    a[i] *= f;
    }
    public String toString() {
        String s = "(";
	for (int i = 0; i < a.length; i++)
	    s += (i > 0 ? "," : "") + a[i];
	return s + ")";
    }
    public Object clone() {
        try {
	    // Object.clone() erzeugt byteweise Kopie
	    // mit demselben dynamischen Typ (hier Copy):
	    Vector v = (Vector) super.clone();
	    // ... das reicht hier aber nicht aus,
	    // denn es wurde nur der Referenzwert von a
	    // und nicht das Array kopiert! (=> a verweist
	    // auf dasselbe Array!)
	    v.a = (int[]) a.clone();
	    return v;
        }
	catch (CloneNotSupportedException e) {
	    // Transformation in eine ungepruefte Ausnahme
	    throw new RuntimeException("Unexpected exception: "+e);
	}
    }

    public static void main(String[] args) {
        Vector u = new Vector(new int[] {1, 2, 3});
	System.out.println("u = "+u);

        Vector v = (Vector) u.clone();
	System.out.println("v = "+v);

	v.multiplyBy(2);

	System.out.println("u = "+u);
	System.out.println("v = "+v);
    }
}
